@@ -37,6 +37,53 @@ pub enum Value {
     Dict(Dict),
 }
 
+impl fmt::Display for Value {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match *self {
+            Value::Int(int) => write!(f, "{}", int),
+            Value::Text(ref bytes) => {
+                let v = String::from_utf8_lossy(bytes);
+                write!(f, "\"{}\"", &v)
+            }
+            Value::List(ref list) => {
+                f.write_str("[")?;
+
+                let mut first = true;
+                for elem in list {
+                    if !first {
+                        write!(f, ", ")?;
+                    }
+
+                    write!(f, "{}", elem)?;
+                    first = false;
+                }
+
+                f.write_str("]")
+            }
+            Value::Dict(ref dict) => {
+                f.write_str("{")?;
+
+                let mut first = true;
+                for (key, val) in dict {
+                    if first {
+                        first = false;
+                        f.write_str(" ")?;
+                    } else {
+                        f.write_str(", ")?;
+                    }
+                    write!(f, "{}: {}", key, val)?;
+                }
+
+                if !first {
+                    f.write_str(" ")?;
+                }
+
+                f.write_str("}")
+            }
+        }
+    }
+}
+
 impl Value {
     /// Returns an `i64` if the value is an `Int`. Otherwise, `None` is returned.
     ///
@@ -130,7 +177,7 @@ impl Value {
     ///
     /// let val = Value::List(vec![Value::Int(50), Value::Text(b"foo".to_vec())]);
     /// for elem in val.as_list().unwrap() {
-    ///     println!("{:?}", elem);   
+    ///     println!("{:?}", elem);
     /// }
     /// ```
     pub fn as_list(&self) -> Option<&[Value]> {
@@ -368,19 +415,19 @@ mod test {
 
     #[test]
     fn encode_value_int() {
-        let mut val = Value::Int(1995);
+        let val = Value::Int(1995);
         assert_eq!(encode(&val).unwrap(), b"i1995e");
     }
 
     #[test]
     fn encode_value_text() {
-        let mut val = Value::Text(b"foo".to_vec());
+        let val = Value::Text(b"foo".to_vec());
         assert_eq!(encode(&val).unwrap(), b"3:foo");
     }
 
     #[test]
     fn encode_value_list() {
-        let mut val =
+        let val =
             Value::List(vec![Value::Int(1995), Value::Text(b"foo".to_vec())]);
         assert_eq!(encode(&val).unwrap(), b"li1995e3:fooe");
     }
